@@ -97,7 +97,7 @@ class GUI_App(Ui_MainWindow, QObject):
     def helpButton(self):
         helpBut = QtWidgets.QMessageBox()
         helpBut.setFixedSize(1000, 10000)
-        helpBut.setWindowTitle("How to Use CU TRaIL Data Reduction")
+        helpBut.setWindowTitle("How to Use HeCalc")
         # f = open('HTMLhelpmsg.txt', "r")
         # msg = f.read()
         # f.close()
@@ -108,10 +108,10 @@ class GUI_App(Ui_MainWindow, QObject):
     # Generate an about window with version and contact info
     def aboutButton(self):
         aboutBut = QtWidgets.QMessageBox()
-        aboutBut.setWindowTitle("About CU TRaIL Data Reduction")
+        aboutBut.setWindowTitle("About HeCalc")
         aboutBut.setText(
             '''<html><head/><body><p align=\"center\" style=\"font-size:14px\">
-            v0.0 | Dec. 15 2020<br/>Contact: Peter E. Martin
+            v0.0.1 | Nov. 11 2021<br/>Contact: Peter E. Martin
             (peter.martin-2@colorado.edu)<br/>Written in Python 3.8 using
             PyQt5</p></body></html>'''
             )
@@ -460,6 +460,7 @@ class WorkerClass(QObject):
                 times = []
                 for i in range(len(data)):
                     while not self.cancel:
+                        starttime = time.time()
                         # Update user of new sample being analyzed
                         self.progress.emit(100 * (len(save_out["Sample"])/len(data)))
                         self.status.emit('Now working on sample ' + str(data['Sample'].iloc[i]))
@@ -502,6 +503,7 @@ class WorkerClass(QObject):
                                                 self.parameterize,
                                                 self.decimals,
                                                 self.prec)
+                        times.append(time.time() - starttime)
                         break
                 
                 # Get the excel book to save
@@ -603,13 +605,11 @@ class WorkerClass(QObject):
                               'Linear raw uncertainty', 'Linear\nraw\n'+u'\u00B1',
                               ' +68% CI raw', '+68%\nCI\nraw',
                               ' -68% CI raw', '-68%\nCI\nraw',
-                              '% Skewness of raw distribution', '% raw\nskew',
                               'Corrected date', 'Corr.\ndate',
                               'Mean corrected date', 'Mean\ncorrected\ndate',
                               'Linear corrected uncertainty', 'Linear\ncorr.\n'+u'\u00B1',
                               ' +68% CI corrected', '+68%\nCI\ncorr.',
-                              ' -68% CI corrected', '-68%\nCI\ncorr.',
-                              '% Skewness of corrected distribution', '% corr.\nskew']
+                              ' -68% CI corrected', '-68%\nCI\ncorr.']
                 for i in range(0,len(key_change),2):
                     if key_change[i] in output.keys():
                         output[key_change[i+1]] = output.pop(key_change[i])
